#include <stdio.h>
#include <stdlib.h>
#include <time.h>
#include <math.h>
#include <omp.h>

int main(int argc, char *argv[]) {
    if(argc != 2) {
        fprintf(stderr, "Uso: %s <tiros>\n", argv[0]);
        return 1;
    }

    printf("Hilos: %d\n", omp_get_max_threads());

    size_t tiros = atoi(argv[1]);

    size_t positivos = 0;

    #pragma omp parallel reduction(+: positivos)
    {
        int seed = time(NULL) + omp_get_thread_num();

        #pragma omp for
        for(size_t i = 0; i < tiros; i++) {
            double x = (double)rand_r(&seed) / RAND_MAX;
            double y = (double)rand_r(&seed) / RAND_MAX;
            if(x * x + y * y < 1)
                positivos++;
        }
    }

    double pi = 4.0 * positivos / tiros;

    printf("Tiros = %zd, Positivos = %zd\n", tiros, positivos);
    printf("π ~= %.15f\n", pi);
    printf("ε = %f%%\n", 100 * fabs(M_PI - pi) / M_PI);
    return 0;
}

